@@ -1,40 +1,3 @@
-#' Combine two time series in one
-#'
-#' The function combines several ts vectors in one, maintaining the structure
-#' of the time series
-#'
-#' The function will combine ts objects in a ts vector, using the frequency and the start of
-#' the first one. So, if you combine several time series, they will be stacked one after
-#' another.
-#'
-#' @template author
-#'
-#' @param ...  The ts vectors to combine.
-#' @return This function returns the ts vector.
-#' @seealso \link[base]{c}
-#' @keywords htest
-#' @examples
-#'
-#' x <- ts(rnorm(120,100,10), frequency=12)
-#' x1 <- window(x, 1, 8+11/12)
-#' x2 <- window(x, 9)
-#' c(x1,x2)
-#' c(x2,x1)
-#'
-#' @export
-c.ts <- function(...){
-    ellipsis <- list(...);
-    # tsFrequencies <- sapply(ellipsis, frequency);
-    # startTimes <- sapply(lapply(ellipsis, time), min);
-    # tsOrders <- order(startTimes);
-    # startTimes <- startTimes[tsOrders];
-    # if(any(tsOrders!=c(1:length(tsOrders)))){
-    #     ellipsis <- ellipsis[tsOrders];
-    # }
-
-    return(ts(unlist(ellipsis), start=start(ellipsis[[1]]), frequency=frequency(ellipsis[[1]])));
-}
-
 ##### IC functions #####
 
 #' Corrected Akaike's Information Criterion and Bayesian Information Criterion
